@@ -18,7 +18,7 @@
  *
  * Contributors:
  *
- * $Header: /opt/cvs/Regina/regutil/regfilesys.c,v 1.20 2022/08/21 23:16:42 mark Exp $
+ * $Header: /opt/cvs/Regina/regutil/regfilesys.c,v 1.22 2023/05/25 22:14:31 mark Exp $
  */
 #ifdef __EMX__
 # define INCL_DOSFILEMGR
@@ -1121,7 +1121,6 @@ rxfunc(sysrmdir)
     return 0;
 }
 
-
 /* SysSearchPath(path,filename) */
 rxfunc(syssearchpath)
 {
@@ -1130,7 +1129,7 @@ rxfunc(syssearchpath)
 #else
    const char delim[] = ":", pathpat[] = "%s/%s";
 #endif
-   char *pathseg, *pseg, *rpath, *path, *pathname, *filename;
+   char *pathseg, *pseg, *rpath, *path, *pathname, *filename, *env=NULL;
    int len;
 
    checkparam(2, 2);
@@ -1141,13 +1140,11 @@ rxfunc(syssearchpath)
    /* return empty string if not found */
    result ->strlength = 0;
 
-   rpath = getenv(pathname);
-
+   rpath = rxgetenv(pathname,env,0);
    if (rpath != NULL) {
       len = strlen(rpath) + 1;
       path = alloca(len);
       memcpy(path, rpath, len);
-
       pathseg = alloca(len+argv[1].strlength+sizeof(pathpat));
 
       for (pseg = strtok(path, delim); pseg; pseg = strtok(NULL, delim)) {
@@ -1160,7 +1157,7 @@ rxfunc(syssearchpath)
           }
       }
    }
-
+   if ( rpath ) free( rpath );
    return 0;
 }
 
